@@ -1,14 +1,11 @@
 # -*- coding: utf-8 -*-
 from json import JSONEncoder
 
-from httpdbg.hook import HTTPRecords
-from httpdbg.hook import HTTPRecord
+from httpdbg.records import HTTPRecords
+from httpdbg.records import HTTPRecord
 from httpdbg.webapp.preview import generate_preview
 
 
-httpdebugk7 = HTTPRecords()
-
-
 class RequestPayload(JSONEncoder):
     def default(self, req):
         assert isinstance(
@@ -20,25 +17,27 @@ class RequestPayload(JSONEncoder):
             "method": req.method,
             "status_code": req.status_code,
             "reason": req.reason,
-            "request": {
-                "headers": req.request.headers,
-                "cookies": req.request.cookies,
-            },
+            "request": None,
             "response": None,
             "exception": None,
             "initiator": req.initiator.to_json(),
         }
 
-        if req.request.content:
-            payload["request"]["body"] = generate_preview(
-                f"/request/{req.id}/up",
-                "upload",
-                req.request.get_header("Content-Type"),
-                req.request.content,
-            )
+        if req.request is not None:
+            payload["request"] = {
+                "headers": req.request.headers,
+                "cookies": req.request.cookies,
+            }
+
+            if req.request.content:
+                payload["request"]["body"] = generate_preview(
+                    f"/request/{req.id}/up",
+                    "upload",
+                    req.request.get_header("Content-Type"),
+                    req.request.content,
+                )
 
         if req.response is not None:
-
             payload["response"] = {
                 "headers": req.response.headers,
                 "cookies": req.response.cookies,
@@ -55,7 +54,6 @@ class RequestPayload(JSONEncoder):
                 )
 
         if req.exception is not None:
-
             payload["exception"] = {
                 "type": str(type(req.exception)),
                 "message": str(req.exception),
@@ -65,15 +63,14 @@ class RequestPayload(JSONEncoder):
 
 
 class RequestListPayload(JSONEncoder):
-    def default(self, reqs):
+    def default(self, records):
         assert isinstance(
-            reqs, HTTPRecords
+            records, HTTPRecords
         ), "This encoder works only for HTTPRecords object."
 
-        payload = {"id": reqs.id, "requests": {}}
-
-        for id, req in reqs.requests.items():
+        payload = {"id": records.id, "requests": {}}
 
+        for id, req in records.requests.items():
             payload["requests"][id] = {
                 "id": req.id,
                 "url": req.url,
@@ -83,6 +80,7 @@ class RequestListPayload(JSONEncoder):
                 "reason": req.reason,
                 "verb": req.method,
                 "initiator": req.initiator.to_json(full=False),
+                "last_update": req.last_update,
             }
 
         return payload
